# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/lorem/ar_AA/__init__.py

lorem_word_list_ar_aa <- c(
  "\u062a\u0627\u0631\u064a\u062e",
  "\u062b\u0645\u0651\u0629",
  "\u0648\u064a\u0643\u064a\u0628\u064a\u062f\u064a\u0627",
  "\u0648\u0627\u0634\u062a\u062f\u0651\u062a",
  "\u0639\u0646",
  "\u0623\u0648\u0631\u0648\u0628\u0627",
  "\u0627\u0644\u062a\u063a\u064a\u064a\u0631\u0627\u062a",
  "\u0643\u062b\u064a\u0631\u0629",
  "\u0633\u0646\u063a\u0627\u0641\u0648\u0631\u0629",
  "\u0627\u0644\u0644\u0627\u0632\u0645\u0629",
  "\u062c\u064f\u0644",
  "\u0642\u062f",
  "\u0623\u0646",
  "\u0627\u0644\u0634\u0651\u0639\u0628\u064a\u0646",
  "\u0644\u0644\u062c\u0632\u0631",
  "\u0628\u0627\u0644\u0634\u0631\u0642\u064a",
  "\u0630\u0627\u062a",
  "\u0648\u0627\u0644\u062a\u064a",
  "\u0646\u0647\u0627\u064a\u0629",
  "\u0639\u0631\u0641\u0647\u0627",
  "\u0648\u0633\u0641\u0646",
  "\u0648\u0628\u0648\u0644\u0646\u062f\u0627",
  "\u0628\u0627\u0644\u0645\u0637\u0627\u0644\u0628\u0629",
  "\u0648\u0642\u0648\u0639\u0647\u0627",
  "\u0645\u0639\u0627\u0645\u0644\u0629",
  "\u0627\u0644\u0639\u0635\u0628\u0629",
  "\u0644\u0645\u0651",
  "\u0627\u0644\u0628\u0631\u064a\u0629",
  "\u0628\u0639\u062f\u0645",
  "\u0648\u0627\u064f\u0633\u062f\u0644",
  "\u062d\u0627\u0644\u064a\u0629",
  "\u0641\u0645\u0631\u0651",
  "\u0642\u0628\u0636\u062a\u0647\u0645",
  "\u0648\u0625\u0642\u0627\u0645\u0629",
  "\u0627\u0644\u0623\u0639\u0645\u0627\u0644",
  "\u0645\u0639\u0627\u0631\u0636\u0629",
  "\u0627\u0644\u0625\u0645\u062a\u0639\u0627\u0636",
  "\u0662\u0660\u0660\u0664",
  "\u0643\u0627\u0646\u062a",
  "\u0628\u064a\u0646\u0645\u0627",
  "\u0634\u0639\u0627\u0631",
  "\u0648\u062a\u0632\u0648\u064a\u062f\u0647",
  "\u0645\u0639\u0642\u0644",
  "\u0639\u0634\u0648\u0627\u0626\u064a\u0629",
  "\u0645\u062f\u064a\u0646\u0629",
  "\u0648\u0641\u064a",
  "\u0627\u0644\u0623\u0648\u0631\u0648\u0628\u064a\u0651\u0648\u0646",
  "\u0641\u0643\u0627\u0646",
  "\u0636\u0631\u0628",
  "\u0633\u0643\u0627\u0646",
  "\u0627\u0644\u0623\u0648\u0631\u0648\u0628\u064a\u0629",
  "\u0627\u0644\u0623\u0645\u0631\u064a\u0643\u064a",
  "\u0648\u0628\u063a\u0637\u0627\u0621",
  "\u0627\u0644\u0631\u0628\u064a\u0639",
  "\u0627\u0644\u0645\u0636\u064a",
  "\u062c\u062f\u0648\u0644",
  "\u0627\u0644\u062a\u0642\u0644\u064a\u062f\u064a\u0629",
  "\u0627\u0644\u0639\u0627\u0635\u0645\u0629",
  "\u0627\u0644\u062a\u0646\u0627\u0632\u0644\u064a",
  "\u0625\u0628\u0651\u0627\u0646",
  "\u0628\u0647\u0627",
  "\u0627\u0644\u062c\u0646\u0648\u0628\u064a",
  "\u0648\u062a\u0646\u0627\u0645\u062a",
  "\u0627\u0633\u062a\u062f\u0639\u0649",
  "\u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629",
  "\u0628\u0627\u0644\u062a\u0648\u0642\u064a\u0639",
  "\u0628\u062f\u0627\u064a\u0629",
  "\u062f\u062e\u0648\u0644",
  "\u0623\u062b\u0631\u0647",
  "\u0627\u0644\u062f\u0646\u0645\u0627\u0631\u0643",
  "\u0648\u0627\u0642\u062a\u0635\u0627\u0631",
  "\u0627\u0644\u0633\u0627\u062d\u0644",
  "\u0627\u0644\u0648\u0632\u0631\u0627\u0621",
  "\u0627\u0644\u062b\u0627\u0644\u062b",
  "\u062a\u0648\u0646\u0633",
  "\u0627\u0644\u062e\u0627\u0633\u0631\u0629",
  "\u0627\u0644\u062d\u064a\u0644\u0648\u0644\u0629",
  "\u0644\u0641\u0634\u0644",
  "\u0627\u0644\u0625\u0637\u0644\u0627\u0642",
  "\u0645\u0627\u0630\u0627",
  "\u0645\u0648\u0627\u0642\u0639\u0647\u0627",
  "\u0627\u0644\u062c\u062f\u064a\u062f\u0629",
  "\u0648\u0627\u0644\u0646\u0641\u064a\u0633",
  "\u0627\u0644\u0623\u0631\u0648\u0627\u062d",
  "\u0623\u0643\u062b\u0631",
  "\u0627\u0644\u0623\u0648\u0631\u0628\u064a\u064a\u0646",
  "\u0648\u0627\u0644\u0641\u0631\u0646\u0633\u064a",
  "\u0623\u0648\u0632\u0627\u0631",
  "\u0628\u0644\u062f\u064a\u0647\u0645\u0627",
  "\u0648\u0627\u064a\u0631\u0644\u0646\u062f\u0627",
  "\u064a\u062a\u0645",
  "\u062c\u0639\u0644",
  "\u0639\u0631\u0636",
  "\u0623\u0641\u0631\u064a\u0642\u064a\u0627",
  "\u0625\u0633\u062a\u0639\u0645\u0644",
  "\u0627\u0644\u062a\u0642\u0644\u064a\u062f\u064a",
  "\u0639\u064f\u0642\u0631",
  "\u0637\u0648\u0643\u064a\u0648",
  "\u0627\u062a\u0641\u0627\u0642\u064a\u0629",
  "\u0628\u0645\u062d\u0627\u0648\u0644\u0629",
  "\u0627\u0648\u0631\u0648\u0628\u0627",
  "\u0645\u0646\u062a\u0635\u0641",
  "\u0623\u0633\u0631",
  "\u0628\u0627\u0644\u0631\u0651\u063a\u0645",
  "\u0628\u0636\u0631\u0628",
  "\u0625\u062d\u0643\u0627\u0645",
  "\u0623\u062c\u0632\u0627\u0621",
  "\u0627\u0644\u062e\u0627\u0631\u062c\u064a\u0629",
  "\u0643\u0646\u0642\u0637\u0629",
  "\u0628\u0634\u0631\u064a\u0629",
  "\u0628\u0642\u0627\u062f\u0629",
  "\u0644\u0628\u0644\u062c\u064a\u0643\u0627",
  "\u0627\u0633\u062a\u0637\u0627\u0639\u0648\u0627",
  "\u0628\u0633\u0628\u0628",
  "\u062a\u0633\u0645\u0651\u0649",
  "\u0627\u0644\u062d\u0631\u0629",
  "\u064a\u0631\u062a\u0628\u0637",
  "\u0634\u0627\u0633\u0639\u0629",
  "\u0627\u0644\u0648\u0627\u0642\u0639\u0629",
  "\u0645\u0627\u0631\u062f",
  "\u0648\u0627\u0644\u0645\u0639\u062f\u0627\u062a",
  "\u0644\u0645\u062d\u0627\u0643\u0645",
  "\u0628\u0639\u0644\u0649",
  "\u0627\u0644\u062a\u0628\u0631\u0639\u0627\u062a",
  "\u0636\u0645\u0646\u0647\u0627",
  "\u0641\u0639\u0644",
  "\u0663\u0660",
  "\u0627\u0644\u0627\u0646\u062f\u0648\u0646\u064a\u0633\u064a\u0629",
  "\u0627\u0644\u0649",
  "\u0645\u0643\u062b\u0651\u0641\u0629",
  "\u0648\u0642\u062f\u0651\u0645\u0648\u0627",
  "\u0627\u0644\u0623\u062b\u0646\u0627\u0646",
  "\u0623\u062e\u0631\u0649",
  "\u0627\u0644\u0639\u0627\u0644\u0645\u064a",
  "\u0648\u0627\u062d\u062f\u0629",
  "\u0648\u062a\u0631\u0643",
  "\u0627\u0644\u062d\u0643\u0645",
  "\u0628\u0647\u0646\u0627\u0643",
  "\u0628\u0623\u064a\u062f\u064a",
  "\u0628\u0627\u0633\u062a\u062e\u062f\u0627\u0645",
  "\u0627\u0644\u0630\u0648\u062f",
  "\u0648\u0644\u0643\u0633\u0645\u0628\u0648\u0631\u063a",
  "\u0628\u0639\u0634\u0648\u0627\u0626\u064a\u0629",
  "\u0627\u0644\u0623\u0648\u0636\u0627\u0639",
  "\u0631\u062c\u0648\u0639\u0647\u0645",
  "\u0648\u0623\u0632\u064a\u0632",
  "\u0633\u064a\u0627\u0633\u0629",
  "\u0644\u064a\u0628\u064a\u0646",
  "\u0631\u0626\u064a\u0633",
  "\u0627\u0644\u062c\u0648\u064a",
  "\u0633\u0642\u0637\u062a",
  "\u062a\u0643\u0627\u0644\u064a\u0641",
  "\u0648\u0643\u0633\u0628\u062a",
  "\u0648\u0639\u0644\u0649",
  "\u0627\u062d\u062f\u0627\u062b",
  "\u0634\u0645\u0648\u0644\u064a\u0629\u064b",
  "\u0625\u064a\u0637\u0627\u0644\u064a\u0627",
  "\u0639\u062c\u0651\u0644",
  "\u0623\u062d\u0643\u0645",
  "\u0627\u0644\u062f\u0645\u062c",
  "\u0645\u062d\u0627\u0648\u0644\u0627\u062a",
  "\u064a\u0639\u0627\u062f\u0644",
  "\u0628\u0631\u064a\u0637\u0627\u0646\u064a\u0627-\u0641\u0631\u0646\u0633\u0627",
  "\u062f\u064a\u0633\u0645\u0628\u0631",
  "\u0642\u062a\u064a\u0644",
  "\u0627\u0644\u062a\u0627\u0631\u064a\u062e",
  "\u0627\u0633\u062a\u0628\u062f\u0627\u0644",
  "\u0645\u0642\u0627\u0648\u0645\u0629",
  "\u0627\u0644\u0633\u064a\u0621",
  "\u0627\u0644\u0635\u0639\u062f\u0627\u0621",
  "\u0623\u0639\u0645\u0627\u0644",
  "\u0645\u0633\u0627\u0631\u062d",
  "\u0648\u0645\u0636\u0649",
  "\u062a\u0639\u062f",
  "\u0635\u0641\u062d\u0629",
  "\u0627\u0644\u0646\u0641\u0637",
  "\u0648\u0647\u0648\u0644\u0646\u062f\u0627",
  "\u0648\u0628\u0631\u064a\u0637\u0627\u0646\u064a\u0627",
  "\u062c\u0647\u0629",
  "\u0628\u064a\u0646",
  "\u0627\u062a\u0651\u062c\u0629",
  "\u0648\u0627\u0639\u062a\u0644\u0627\u0621",
  "\u0648\u0645\u062d\u0627\u0648\u0644\u0629",
  "\u0627\u0644\u0645\u0627\u0631\u0642",
  "\u0627\u0644\u0645\u0624\u0644\u0651\u0641\u0629",
  "\u0634\u0645\u0627\u0644",
  "\u0644\u0647\u0630\u0647",
  "\u0628\u062d\u062b",
  "\u0648\u0627\u0646\u0647\u0627\u0621",
  "\u063a\u0631\u064a\u0645\u0647",
  "\u0648\u0628\u062d\u0644\u0648\u0644",
  "\u0648\u0642\u0628\u0644",
  "\u0628\u062a\u0635\u0641\u062d",
  "\u0628\u0627\u0644",
  "\u0627\u0644\u0641\u0631\u0646\u0633\u064a",
  "\u0648\u0633\u0645\u0651\u064a\u062a",
  "\u062a\u0631\u062a\u064a\u0628",
  "\u0648\u0627\u0633\u062a\u0645\u0631\u062a",
  "\u0628\u0628\u0644\u0627",
  "\u0627\u0644\u062f\u0648\u0644\u0627\u0631\u0627\u062a",
  "\u0625\u0639\u0645\u0627\u0631",
  "\u0625\u0639\u0627\u062f\u0629",
  "\u0628\u0647",
  "\u0627\u0644\u0636\u063a\u0648\u0637",
  "\u062d\u0635\u062f\u062a",
  "\u0628\u0642\u0633\u0648\u0629",
  "\u0627\u0644\u0637\u0631\u064a\u0642",
  "\u0648\u0627\u0646\u062a\u0647\u0627\u0621\u064b",
  "\u062d\u0648\u0644",
  "\u0627\u0643\u062a\u0648\u0628\u0631",
  "\u0627\u0644\u062e\u0627\u0633\u0631",
  "\u0627\u064a\u0637\u0627\u0644\u064a\u0627",
  "\u0644\u0644\u0623\u0631\u0627\u0636\u064a",
  "\u0639\u0627\u0644\u0645\u064a\u0629",
  "\u062c\u062f\u064a\u062f\u0629",
  "\u0623\u062e\u0631",
  "\u063a\u064a\u0646\u064a\u0627",
  "\u0642\u064f\u062f\u064f\u0645\u0627\u064b",
  "\u0648",
  "\u0645\u0633\u0624\u0648\u0644\u064a\u0629",
  "\u0627\u0628\u062a\u062f\u0639\u0647\u0627",
  "\u0623\u0645\u0651\u0627",
  "\u0627\u0644\u0623\u0648\u0644",
  "\u0623\u062f\u0648\u0627\u062a",
  "\u064a\u0637\u0648\u0644",
  "\u062a\u064f\u0635\u0628",
  "\u0627\u0644\u0623\u0648\u0644\u0649",
  "\u0627\u0644\u0645\u0633\u0631\u062d",
  "\u0628\u0647\u064a\u0626\u0629",
  "\u0627\u0644\u062e\u0637\u0651\u0629",
  "\u0645\u0648\u0627\u0644\u064a\u0629",
  "\u0645\u0644\u064a\u0648\u0646",
  "\u0628\u0627\u0644\u062c\u0627\u0646\u0628",
  "\u0625\u064a\u0648",
  "\u0627\u0644\u0647\u062c\u0648\u0645",
  "\u0623\u0639\u0644\u0646\u062a",
  "\u0627\u0644\u0645\u062f\u0646",
  "\u0639\u0644\u0627\u0642\u0629",
  "\u0628\u0627\u0633\u062a\u062d\u062f\u0627\u062b",
  "\u0627\u0646\u062a\u0628\u0627\u0647",
  "\u0628\u0627\u0644\u0648\u0644\u0627\u064a\u0627\u062a",
  "\u0645\u062f\u0646",
  "\u0623\u0633\u0627\u0633\u064a",
  "\u0644\u0641\u0631\u0646\u0633\u0627",
  "\u0627\u0644\u062c\u0646\u0648\u0628",
  "\u0627\u0644\u062b\u0642\u064a\u0644",
  "\u0648\u0627\u0644\u0639\u062a\u0627\u062f",
  "\u0628\u0642\u0639\u0629",
  "\u0627\u0644\u0639\u062f\u0651",
  "\u0627\u062a\u0641\u0627\u0642",
  "\u062a\u062d\u062a",
  "\u0627\u0644\u0625\u062d\u062a\u0641\u0627\u0638",
  "\u0628\u0648\u0642\u0627\u0645\u062a",
  "\u0627\u0644\u062a\u064a",
  "\u0628\u0660\u0668\u0660\u0664",
  "\u0648\u0644\u0627\u062a\u0651\u0633\u0627\u0639",
  "\u0627\u0644\u0627",
  "\u062d\u0643\u0648\u0645\u0629",
  "\u0645\u0645\u0627",
  "\u0628\u062d\u064a\u062b",
  "\u0645\u0644\u064a\u0627\u0631\u0627\u062a",
  "\u0634\u0648\u0627\u0637\u064a\u0621",
  "\u0627\u0644\u062a\u062d\u0627\u0644\u0641",
  "\u0627\u0644\u0623\u0648\u0631\u0648\u0628\u064a",
  "\u0642\u0627\u0645",
  "\u064a\u062a\u0639\u0644\u0651\u0642",
  "\u0645\u0627\u064a\u0648",
  "\u0647\u0627\u0631\u0628\u0631",
  "\u0627\u0644\u0639\u0645\u0644\u064a\u0627\u062a",
  "\u0623\u0645\u0627",
  "\u064a\u0639\u0628\u0623",
  "\u0648\u0634\u0639\u0627\u0631",
  "\u0627\u0644\u0625\u0642\u062a\u0635\u0627\u062f\u064a\u0629",
  "\u0648\u0627\u0644\u0643\u0633\u0627\u062f",
  "\u0644\u064a\u0631\u062a\u0641\u0639",
  "\u0648\u0628\u0627\u0644\u0631\u063a\u0645",
  "\u0642\u0650\u0628\u0644",
  "\u0627\u0644\u0644\u0647",
  "\u062a\u0643\u062a\u064a\u0643\u0627\u064b",
  "\u0627\u0639\u062a\u062f\u0627\u0621",
  "\u0628\u0663\u0660",
  "\u062a\u0633\u0628\u0628",
  "\u0644\u0644\u062d\u0643\u0648\u0645\u0629",
  "\u0627\u0644\u0623\u0647\u062f\u0627\u0641",
  "\u0627\u0644\u0644\u0627",
  "\u0628\u0628\u0639\u0636",
  "\u0627\u0644\u0633\u062a\u0627\u0631",
  "\u0648\u0628\u0644\u062c\u064a\u0643\u0627",
  "\u0648\u0641\u0646\u0644\u0646\u062f\u0627",
  "\u0645\u064a\u0646\u0627\u0621",
  "\u0627\u0644\u0633\u0627\u062d\u0644\u064a\u0629",
  "\u0645\u0642\u0627\u0637\u0639\u0629",
  "\u0648\u062a\u0645",
  "\u0627\u0644\u0633\u064a\u0637\u0631\u0629",
  "\u062a\u063a\u064a\u064a\u0631\u0627\u062a",
  "\u0648\u0648\u0635\u0641",
  "\u0627\u0644\u062c\u0646\u0648\u062f",
  "\u0628\u0644\u0645\u0651",
  "\u0644\u062f\u062d\u0631",
  "\u0628\u0627\u0644\u062d\u0631\u0628",
  "\u0643\u064f\u0644\u0641\u0629",
  "\u0648\u0628\u062f\u0648\u0646",
  "\u0648\u0635\u0644",
  "\u0623\u0641\u0627\u0642",
  "\u0627\u0644\u0623\u0628\u0631\u064a\u0627\u0621",
  "\u0645\u0647\u0645\u0651\u0627\u062a",
  "\u0627\u0644\u0639\u0638\u0645\u0649",
  "\u0648\u0627\u0644\u0642\u0631\u0649",
  "\u0648\u0623\u0643\u062b\u0631\u0647\u0627",
  "\u0644\u0627\u0646",
  "\u0645\u0634\u0627\u0631\u0641",
  "\u0645\u0633\u0627\u0639\u062f\u0629",
  "\u0623\u0636\u0641",
  "\u0645\u0634\u0631\u0648\u0637",
  "\u0627\u0644\u0643\u0648\u0646\u062c\u0631\u0633",
  "\u0644\u0644\u0635\u064a\u0646",
  "\u0627\u0644\u0634\u0645\u0644",
  "\u0627\u0644\u064a\u0645\u064a\u0646\u064a",
  "\u0641\u0643\u0627\u0646\u062a",
  "\u0633\u0642\u0648\u0637",
  "\u0628\u062a\u062d\u062a",
  "\u0628\u0643\u0644\u0627",
  "\u062a\u0635\u0631\u0651\u0641",
  "\u0627\u0644\u0623\u062b\u0646\u0627\u0621",
  "\u0628\u0648\u0644\u0646\u062f\u0627",
  "\u0648\u0627\u0646\u062f\u0648\u0646\u064a\u0633\u064a\u0627",
  "\u0643\u0644\u0651",
  "\u0625\u062d\u062a\u0627\u0631",
  "\u0627\u0644\u062e\u0627\u0637\u0641\u0629",
  "\u0643\u0631\u062f\u0629",
  "\u0648\u062d\u0644\u0641\u0627\u0624\u0647\u0627",
  "\u0625\u062a\u0641\u0627\u0642\u064a\u0629",
  "\u0648\u0628\u062f\u0627\u064a\u0629",
  "\u064a\u0630\u0643\u0631",
  "\u062d\u0627\u062f\u062b\u0629",
  "\u0645\u0626\u0627\u062a",
  "\u0627\u0644\u0623\u0633\u064a\u0648\u064a",
  "\u063a\u064a\u0631",
  "\u0627\u0644\u0627\u0646\u062c\u0644\u064a\u0632\u064a\u0629",
  "\u0627\u0633\u062a\u0639\u0645\u0644\u062a",
  "\u0627\u0633\u062a\u0645\u0631\u0627\u0631",
  "\u0627\u0644\u0645\u062d\u064a\u0637",
  "\u0648\u0635\u0627\u0641\u0631\u0627\u062a",
  "\u0648\u062d\u062a\u0651\u0649",
  "\u0627\u0644\u062e\u0627\u0635\u0651\u0629",
  "\u0648\u0632\u0627\u0631\u0629",
  "\u0628\u062d\u0642",
  "\u0628\u062f\u0627\u0631\u062a",
  "\u0645\u0627\u0644\u064a\u0632\u064a\u0627",
  "\u062c\u0632\u064a\u0631\u062a\u064a",
  "\u0627\u0644\u064a\u0627\u0628\u0627\u0646",
  "\u0647\u0627\u0645\u0634",
  "\u0628\u0648\u0627\u0628\u0629",
  "\u0648\u062c\u0647\u0627\u0646",
  "\u0648\u0642\u0631\u0649",
  "\u062a\u062c\u0647\u064a\u0632",
  "\u0628\u0648\u0644\u0645",
  "\u0627\u0644\u0628\u0648\u0644\u0646\u062f\u064a",
  "\u0627\u0644\u062c\u0648",
  "\u0644\u0643\u0644",
  "\u0641\u0631\u0646\u0633\u064a\u0629",
  "\u062a\u062d\u0631\u0651\u0643\u062a",
  "\u064a\u0642\u0648\u0645",
  "\u0648\u0644\u0645",
  "\u0644\u0644\u0625\u062a\u062d\u0627\u062f",
  "\u0627\u0644\u063a\u0627\u0644\u064a",
  "\u0627\u0644\u0645\u0634\u062a\u0631\u0643",
  "\u0627\u0644\u062a\u0643\u0627\u0644\u064a\u0641",
  "\u0628\u0648\u0644\u0627\u062a\u0651\u0633\u0627\u0639",
  "\u0627\u0644\u0641\u0631\u0646\u0633\u064a\u0629",
  "\u0628\u062a\u062d\u062f\u0651\u064a",
  "\u063a\u0631\u0651\u0629",
  "\u0627\u0644\u0623\u0631\u0636",
  "\u0645\u0634\u0627\u0631\u0643\u0629",
  "\u0641\u0635\u0644",
  "\u0628\u0623\u0645",
  "\u0648\u0627\u0644\u0643\u0648\u0631\u064a",
  "\u0648\u0642\u062f",
  "\u0628\u0640",
  "\u0643\u0644",
  "\u0628\u0632\u0645\u0627\u0645",
  "\u0623\u064a",
  "\u0645\u0627\u0634\u0627\u0621",
  "\u0644\u063a\u0627\u062a",
  "\u0627\u0644\u064a\u0627\u0628\u0627\u0646\u064a\u0629",
  "\u0648\u0646\u062a\u062c",
  "\u0627\u0644\u0636\u0631\u0648\u0631\u064a",
  "\u0645\u0639",
  "\u0639\u0642\u0628\u062a",
  "\u0644\u0644\u064a\u0627\u0628\u0627\u0646",
  "\u0645\u0633\u0631\u062d",
  "\u0641\u0642\u0627\u0645\u062a",
  "\u0628\u062a\u0637\u0648\u064a\u0642",
  "\u0628\u062a\u062e\u0635\u064a\u0635",
  "\u0627\u0644\u0648\u0631\u0627\u0621",
  "\u062a\u0639\u062f\u0627\u062f",
  "\u0641\u0628\u0639\u062f",
  "\u062a\u0634\u0643\u064a\u0644",
  "\u0627\u0644\u0645\u0648\u0633\u0648\u0639\u0629",
  "\u0644\u0643\u0648\u0646",
  "\u0648\u0627\u0633\u062a\u0645\u0631",
  "\u0627\u0644\u0623\u0645\u0631\u064a\u0643\u064a\u0629",
  "\u0625\u062c\u0644\u0627\u0621",
  "\u0628\u062f\u0648\u0646",
  "\u0642\u0631\u0631\u062a",
  "\u0627\u0644\u0634\u062a\u0627\u0621",
  "\u064a\u062a\u0645\u0643\u0646",
  "\u0627\u0644\u062a\u062e\u0637\u064a\u0637",
  "\u0645\u0643\u0646",
  "\u0628\u0631\u064a\u0637\u0627\u0646\u064a\u0627",
  "\u0623\u062d\u062f\u062b",
  "\u062a\u0634\u064a\u0643\u0648\u0633\u0644\u0648\u0641\u0627\u0643\u064a\u0627",
  "\u0648\u0628\u062f\u0623\u062a",
  "\u0627\u0644\u0634\u0647\u064a\u0631\u0629",
  "\u062d\u062f\u0649",
  "\u0627\u0644\u0625\u064a\u0637\u0627\u0644\u064a\u0629",
  "\u064a\u062a\u0633\u0646\u0651\u0649",
  "\u0627\u0642\u062a\u0635\u0627\u062f\u064a\u0629",
  "\u0627\u0644\u062a\u062c\u0627\u0631\u064a\u0629",
  "\u0628\u0634\u0643\u0644",
  "\u0639\u0633\u0643\u0631\u064a\u0627\u064b",
  "\u0639\u0644\u0649",
  "\u0623\u0644\u0645\u0651",
  "\u0644\u0628\u0648\u0644\u0646\u062f\u0627",
  "\u0648\u0633\u0648\u0621",
  "\u062c\u0646\u0648\u0628",
  "\u0628\u0627\u0644\u0634\u062a\u0627\u0621",
  "\u0627\u0644\u0641\u062a\u0631\u0629",
  "\u0644\u0644\u0645\u062c\u0647\u0648\u062f",
  "\u0623\u0633\u064a\u0627",
  "\u0627\u0631\u062a\u0643\u0628\u0647\u0627",
  "\u0628\u0644\u0647\u0627",
  "\u0642\u0627\u0645\u062a",
  "\u0623\u0648\u0631\u0627\u0642\u0647\u0645",
  "\u0628\u062c\u0633\u064a\u0645\u0629",
  "\u0628\u0625\u0639\u0645\u0627\u0631",
  "\u0648\u062a\u062a\u062d\u0645\u0651\u0644",
  "\u0627\u0644\u0642\u0648\u0649",
  "\u0642\u0628\u0644",
  "\u062f\u0646\u0648",
  "\u0639\u062f\u0645",
  "\u062f\u0627\u0631",
  "\u0627\u0644\u0647\u0627\u062f\u064a",
  "\u062e\u0637\u0651\u0629",
  "\u0627\u0644\u0645\u062c\u062a\u0645\u0639",
  "\u0623\u0645\u0644\u0627\u064b",
  "\u062f\u0641\u0651\u0629",
  "\u0628\u062e\u0637\u0648\u0637",
  "\u0627\u0644\u0633\u0641\u0646",
  "\u0644\u0639\u062f\u0645",
  "\u062d\u0627\u0645\u0644\u0627\u062a",
  "\u0628\u0644",
  "\u0627\u0644\u0625\u062a\u0641\u0627\u0642\u064a\u0629",
  "\u0627\u0644\u0623\u0645\u0648\u0631",
  "\u0628\u0627\u0646\u0647",
  "\u0645\u0631\u062c\u0639",
  "\u0627\u0644\u0646\u0632\u0627\u0639",
  "\u0627\u0644\u062f\u0651\u0641\u0627\u0639",
  "\u0628\u0643\u0644\u0651",
  "\u0627\u0646",
  "\u0627\u0644\u0633\u0628\u0628",
  "\u0627\u0644\u0645\u0634\u062a\u0651\u062a\u0648\u0646",
  "\u0648\u062f\u0648\u0644",
  "\u0623\u0644\u0645\u0627\u0646\u064a\u0627",
  "\u0648\u0627\u0644\u0631\u0648\u0633\u064a\u0629",
  "\u0648\u0627\u0644\u0641\u0644\u0628\u064a\u0646",
  "\u0628\u0644\u0627",
  "\u0623\u0648\u0627\u062e\u0631",
  "\u0628\u0628\u0647",
  "\u062a\u0632\u0627\u0645\u0646\u0627\u064b",
  "\u0623\u0637\u0631\u0627\u0641",
  "\u064a\u0648\u0646\u064a\u0648",
  "\u0627\u0644\u0623\u0631\u0627\u0636\u064a",
  "\u0643\u0627\u0646\u062a\u0627",
  "\u0648\u064a\u0639\u0632\u0649",
  "\u0627\u0646\u062a\u0647\u062a",
  "\u0628\u0627\u0644\u062b\u0627\u0644\u062b",
  "\u0648\u0628\u0627\u0633\u062a\u062b\u0646\u0627\u0621",
  "\u0632\u0647\u0627\u0621",
  "\u0627\u0644\u0622\u062e\u0631",
  "\u0623\u062e\u0630",
  "\u0644\u064a\u0631\u0643\u0632",
  "\u064a\u062a\u0628\u0642\u0651",
  "\u062a\u0645\u0647\u064a\u062f",
  "\u0627\u0644\u0625\u0642\u062a\u0635\u0627\u062f\u064a",
  "\u0628\u0627\u0644\u0631\u063a\u0645",
  "\u0633\u0628\u062a\u0645\u0628\u0631",
  "\u0628\u0642\u062f",
  "\u0648\u0627\u062a\u0651\u062c\u0647",
  "\u0648\u0635\u063a\u0627\u0631",
  "\u0627\u0644\u0634\u062a\u0648\u064a\u0629",
  "\u0633\u0627\u0628\u0642",
  "\u0628\u0639\u0636",
  "\u0627\u0644\u0634\u0631\u0642",
  "\u0627\u0644\u0645\u062a\u0633\u0627\u0642\u0637\u0629",
  "\u0627\u0644\u0635\u064a\u0646",
  "\u0627\u0633\u0628\u0648\u0639\u064a\u0646",
  "\u0644\u0647\u064a\u0645\u0646\u0629",
  "\u0627\u0644\u0635\u0641\u062d\u0627\u062a",
  "\u0623\u0645",
  "\u0627\u0644\u0633\u0627\u062d\u0629",
  "\u0627\u0644\u0642\u0627\u062f\u0629",
  "\u0644\u0639\u0645\u0644\u0629",
  "\u0623\u0645\u0627\u0645",
  "\u062a\u062d\u0631\u064a\u0631",
  "\u0639\u0644\u064a\u0647\u0627",
  "\u0648\u062d\u0631\u0645\u0627\u0646",
  "\u062d\u0644\u0651\u062a",
  "\u0628\u0623\u0636\u0631\u0627\u0631",
  "\u0627\u0644\u062b\u0642\u064a\u0644\u0629",
  "\u0648\u062c\u0632\u0631",
  "\u0627\u0644\u0623\u0631\u0636\u064a\u0629",
  "\u0623\u0631\u0627\u0636",
  "\u0648\u0627\u0644\u062d\u0632\u0628",
  "\u0648\u0628\u0627\u0621\u062a",
  "\u062d\u0642\u0648\u0644",
  "\u0648\u0628\u0627\u0644\u062a\u062d\u062f\u064a\u062f",
  "\u0644\u0625\u0646\u0639\u062f\u0627\u0645",
  "\u0627\u0639\u0644\u0627\u0646",
  "\u062e\u0644\u0627\u0641",
  "\u0627\u0646\u0647",
  "\u0628\u062a\u0648\u0646\u0633",
  "\u0628\u0645\u0645\u0627",
  "\u0627\u0644\u0623\u062c\u0644",
  "\u0623\u0648\u0633\u0639",
  "\u0627\u0644\u0622\u0644\u0627\u0641",
  "\u062a\u0637\u0648\u064a\u0631",
  "\u0627\u0644\u064a\u0647\u0627",
  "\u0627\u0644\u0628\u0634\u0631\u064a\u0629\u064b",
  "\u0648\u0627\u0644\u0625\u062a\u062d\u0627\u062f",
  "\u0625\u062e\u062a\u0627\u0631",
  "\u0648\u0628\u0639\u0636",
  "\u0628\u0627\u0644\u0645\u062d\u0648\u0631",
  "\u063a\u0636\u0648\u0646",
  "\u0634\u0631\u0633\u0629",
  "\u0627\u0644\u0633\u0627\u062f\u0633",
  "\u0627\u0644\u0625\u062b\u0646\u0627\u0646",
  "\u0644\u062a\u0642\u0644\u064a\u0639\u0629",
  "\u0627\u0644\u062c\u0646\u0631\u0627\u0644",
  "\u062a\u0635\u0641\u062d",
  "\u062b\u0627\u0646\u064a\u0629",
  "\u0627\u0644\u0639\u0646\u0627\u062f",
  "\u0644\u0645",
  "\u0644\u0625\u0639\u0627\u062f\u0629",
  "\u0633\u0644\u064a\u0645\u0627\u0646",
  "\u0647\u0646\u0627\u0643",
  "\u062c\u0645\u0639\u062a",
  "\u0627\u0644\u0628\u0627\u0647\u0636\u0629",
  "\u0648\u0628\u0639\u062f\u0645\u0627",
  "\u0641\u064a",
  "\u062a\u0646\u0641\u0651\u0633",
  "\u0648\u064a\u062a\u0651\u0641\u0642",
  "\u0642\u062f\u0645\u0627",
  "\u0627\u0644\u0645\u0646\u062a\u0635\u0631",
  "\u062c\u064a\u0648\u0628",
  "\u0627\u0646\u062a\u0635\u0627\u0631\u0647\u0645",
  "\u0642\u0627\u062f\u0629",
  "\u062a\u062d\u0631\u0651\u0643",
  "\u0627\u0644\u0625\u0645\u062f\u0627\u062f",
  "\u0627\u0644\u0635\u064a\u0646\u064a\u0629",
  "\u062c\u0633\u064a\u0645\u0629",
  "\u062a\u0643\u0628\u0651\u062f",
  "\u0648\u0639\u064f\u0631\u0641\u062a",
  "\u0627\u0633\u062a\u0631\u062c\u0627\u0639",
  "\u0641\u0634\u0643\u0651\u0644",
  "\u062f\u0648\u0644",
  "\u0641\u0642\u062f",
  "\u0627\u0644\u0637\u0631\u0641\u064a\u0646",
  "\u0628\u0627\u0644\u0631\u0651\u062f",
  "\u0627\u0644\u0645\u0639\u0627\u0647\u062f\u0627\u062a",
  "\u0627\u0644\u0623\u062e\u0630",
  "\u0644\u0625\u0639\u0644\u0627\u0646",
  "\u0643\u0631\u0633\u064a",
  "\u0643\u0644\u0627",
  "\u0647\u0630\u0627",
  "\u0627\u0644\u0625\u0646\u0630\u0627\u0631",
  "\u0639\u0645\u0644\u064a\u0629",
  "\u0634\u064a\u0621",
  "\u0648\u0645\u0646",
  "\u062c\u064a\u0645\u0627",
  "\u0627\u0644\u0634\u0631\u0642\u064a\u0629",
  "\u0628\u0627\u0644\u0639\u0645\u0644",
  "\u0645\u0627",
  "\u0627\u0644\u0648\u0644\u0627\u064a\u0627\u062a",
  "\u062d\u0627\u0648\u0644",
  "\u062c\u062f\u064a\u062f\u0627\u064b",
  "\u062d\u064a\u0646",
  "\u0627\u0644\u0639\u0627\u0644\u0645",
  "\u0628\u0646\u0642\u0637\u0629",
  "\u062e\u064a\u0627\u0631",
  "\u0628\u0627\u0644\u062c\u0648\u064a",
  "\u0648\u0627\u0644\u062f\u064a\u0648\u0646",
  "\u0628\u0642\u064a\u0627\u062f\u0629",
  "\u0628\u064a\u0643\u0646",
  "\u064a\u0628\u0642",
  "\u0648\u0645\u0637\u0627\u0644\u0628\u0629",
  "\u0623\u0631\u0627\u0636\u064a",
  "\u062d\u062a\u0649",
  "\u0628\u0623\u0631\u0627\u0636\u064a",
  "\u0645\u0639\u0632\u0651\u0632\u0629",
  "\u0627\u0644\u062b\u0627\u0646\u064a\u0629",
  "\u062f\u0648\u0646",
  "\u0628\u0627\u0644\u0633\u064a\u0637\u0631\u0629",
  "\u0646\u062a\u064a\u062c\u0629",
  "\u062f\u0627\u0631\u062a",
  "\u0628\u0627\u0644\u0625\u0646\u0632\u0627\u0644",
  "\u0623\u0645\u062f\u0647\u0627",
  "\u0627\u0644\u0634\u0647\u064a\u0631",
  "\u0645\u0646",
  "\u0628\u0644\u0627\u062f\u0647",
  "\u062a\u0645",
  "\u0627\u0644\u0635\u0641\u062d\u0629",
  "\u0633\u0627\u0639\u0629",
  "\u0627\u0644\u0625\u0643\u062a\u0641\u0627\u0621",
  "\u064a\u0643\u0646",
  "\u0639\u0644",
  "\u0623\u0635\u0642\u0627\u0639",
  "\u0628\u0627\u0644\u0623\u062c\u0644",
  "\u062a\u0644\u0643",
  "\u0625\u0630",
  "\u0627\u0644\u0625\u062a\u062d\u0627\u062f",
  "\u0627\u0644\u0645\u062a\u062d\u062f\u0629",
  "\u0625\u0633\u062a\u064a\u0644\u0627\u0621",
  "\u0628\u0639\u0631\u0636",
  "\u0628\u0641\u0635\u0644",
  "\u0645\u0645\u062b\u0651\u0644\u0629",
  "\u0634\u062f\u0651\u062a",
  "\u0643\u0627\u0646",
  "\u0647\u0646\u0627\u061f",
  "\u0627\u0644\u0645\u0628\u0631\u0645\u0629",
  "\u0627\u0646\u0630\u0627\u0631",
  "\u062a\u0639\u062f\u064a\u0644",
  "\u0644\u064a\u062a\u0633\u0646\u0651\u0649",
  "\u0648\u062a\u0646\u0635\u064a\u0628",
  "\u0642\u0627\u0626\u0645\u0629",
  "\u0627\u0644\u0625\u0646\u0632\u0627\u0644",
  "\u0625\u0639\u0644\u0627\u0646",
  "\u0644\u0644\u0633\u064a\u0637\u0631\u0629",
  "\u0628\u0639\u062f",
  "\u0628\u0627\u0644\u0633\u0627\u062f\u0633",
  "\u0627\u0644\u0639\u0627\u0644\u0645\u064a\u0629",
  "\u0628\u0628\u062d\u0634\u062f",
  "\u0628\u062d\u0634\u062f",
  "\u0625\u0646\u0637\u0644\u0627\u0642",
  "\u0648\u0627\u0644\u0646\u0631\u0648\u064a\u062c",
  "\u0647\u064f\u0632\u0645",
  "\u0641\u0627\u062a\u0651\u0628\u0639",
  "\u0644\u0647\u0627",
  "\u0628\u0623\u0633\u0631",
  "\u0627\u0644\u0634\u0631\u0642\u064a",
  "\u0627\u0644\u0645\u0648\u0627\u062f",
  "\u0627\u0644\u0634\u0645\u0627\u0644",
  "\u0627\u0644\u0623\u062d\u0645\u0631",
  "\u0660\u0668\u0660\u0664",
  "\u062b\u0645",
  "\u0646\u0641\u0633",
  "\u0648\u0642\u0627\u0645",
  "\u0639\u062f\u062f",
  "\u0623\u0633\u0627\u0628\u064a\u0639",
  "\u0647\u0648",
  "\u0643\u0645\u0627",
  "\u0648\u062d\u062a\u0649",
  "\u0627\u0644\u0645\u062a\u0627\u062e\u0645\u0629",
  "\u0623\u0647\u0651\u0644",
  "\u0623\u062f\u0646\u0649",
  "\u0628\u0641\u0631\u0636",
  "\u0648\u0628\u0639\u062f",
  "\u0627\u0644\u0645\u062a\u0651\u0628\u0639\u0629",
  "\u0628\u0642\u0635\u0641",
  "\u0627\u0644\u062f\u0648\u0644",
  "\u0644\u0623\u062f\u0627\u0621",
  "\u062c\u0648\u0631\u062c",
  "\u0648\u0641\u0631\u0646\u0633\u0627",
  "\u0641\u0631\u0646\u0633\u0627",
  "\u0647\u0630\u0647",
  "\u0627\u0644\u062d\u062f\u0648\u062f",
  "\u0627\u0644\u0634\u0637\u0631",
  "\u0646\u0642\u0637\u0629",
  "\u0628\u062f\u0648\u0644",
  "\u0641\u0647\u0631\u0633\u062a",
  "\u062d\u064a\u062b",
  "\u0627\u0633\u062a\u0631\u0627\u0644\u064a\u0627",
  "\u0648\u0625\u064a\u0637\u0627\u0644\u064a",
  "\u062f\u0623\u0628\u0648\u0627",
  "\u0627\u0644\u062d\u0643\u0648\u0645\u0629",
  "\u0627\u0644\u0623\u0645\u0645",
  "\u0641\u0633\u0642\u0637",
  "\u0645\u0631\u0645\u0649",
  "\u0630\u0644\u0643",
  "\u0645\u0643\u0651\u0646",
  "\u0648\u0625\u0639\u0644\u0627\u0646",
  "\u0628\u0645\u0628\u0627\u0631\u0643\u0629",
  "\u0648\u0627\u0644\u0645\u0627\u0646\u064a\u0627"
)

#' Lorem provider Arabic
#'
#' Methods for Lorem Ipsum generation.
#' Lorem Ipsum is a placeholder text commonly used to demonstrate the visual
#' form of a document or a typeface without relying on meaningful content.
#' @family ar
#' @family AA
#' @export
#' @examples
#' x <- LoremProvider_ar_AA$new()
#' x$word()
#' x$words(3)
#' x$words(6)
#' x$sentence()
#' x$paragraph()
#' x$paragraphs(3)
#' cat(x$paragraphs(6), sep = "\n")
#' x$text(19)
#' x <- LoremProvider_ar_AA$new(word_connector = " --- ")
#' x$paragraph(4)
LoremProvider_ar_AA <- R6::R6Class(
  inherit = LoremProvider,
  "LoremProvider_ar_AA",
  private = list(
    word_list = lorem_word_list_ar_aa,
    locale_ = "ar_AA"
  )
)
